@@ -9,7 +9,7 @@ import os,json
 from lisa.server.web.weblisa.utils import method_restricted_to, is_ajax
 from lisa.server.web.weblisa.settings import LISA_PATH
 
-from ChatterBot.modules.chatterbot import ChatterBot
+from lisa.plugins.ChatterBot.modules.chatterbot import ChatterBot
 
 # Template system will be fixed with Django 1.7. Each plugin will be able to have his own templates
 @login_required()
